/****************************************************************************
** Meta object code from reading C++ file 'dquickbehindwindowblur_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickbehindwindowblur_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickbehindwindowblur_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick22DQuickBehindWindowBlurE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickBehindWindowBlur::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick22DQuickBehindWindowBlurE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickBehindWindowBlur",
        "QML.Element",
        "BehindWindowBlur",
        "cornerRadiusChanged",
        "",
        "blendColorChanged",
        "validChanged",
        "blurEnabledChanged",
        "_q_onHasBlurWindowChanged",
        "_q_updateBlurArea",
        "cornerRadius",
        "blendColor",
        "QColor",
        "valid",
        "blurEnabled"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cornerRadiusChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blendColorChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'validChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blurEnabledChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot '_q_onHasBlurWindowChanged'
        QtMocHelpers::SlotData<void()>(8, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot '_q_updateBlurArea'
        QtMocHelpers::SlotData<void()>(9, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'cornerRadius'
        QtMocHelpers::PropertyData<qreal>(10, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'blendColor'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'valid'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'blurEnabled'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickBehindWindowBlur, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickBehindWindowBlur::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick22DQuickBehindWindowBlurE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick22DQuickBehindWindowBlurE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick22DQuickBehindWindowBlurE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickBehindWindowBlur::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickBehindWindowBlur *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cornerRadiusChanged(); break;
        case 1: _t->blendColorChanged(); break;
        case 2: _t->validChanged(); break;
        case 3: _t->blurEnabledChanged(); break;
        case 4: _t->d_func()->_q_onHasBlurWindowChanged(); break;
        case 5: _t->d_func()->_q_updateBlurArea(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickBehindWindowBlur::*)()>(_a, &DQuickBehindWindowBlur::cornerRadiusChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickBehindWindowBlur::*)()>(_a, &DQuickBehindWindowBlur::blendColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickBehindWindowBlur::*)()>(_a, &DQuickBehindWindowBlur::validChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickBehindWindowBlur::*)()>(_a, &DQuickBehindWindowBlur::blurEnabledChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->cornerRadius(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->blendColor(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->valid(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->blurEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCornerRadius(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setBlendColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setBlurEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickBehindWindowBlur::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickBehindWindowBlur::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick22DQuickBehindWindowBlurE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Dtk::Quick::DQuickBehindWindowBlur::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickBehindWindowBlur::cornerRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickBehindWindowBlur::blendColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickBehindWindowBlur::validChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickBehindWindowBlur::blurEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
